# arpes.plotting.comparison\_tool module

**class
arpes.plotting.comparison\_tool.ComparisonTool(other,**kwargs)\*\*

> Bases:
> [arpes.plotting.interactive\_utils.BokehInteractiveTool](arpes.plotting.interactive_utils#arpes.plotting.interactive_utils.BokehInteractiveTool)
> 
> `auto_rebin = False`
> 
> `auto_zero_nans = False`
> 
> `compared = None`
> 
> `other = None`
> 
> **tool\_handler(doc)**

**arpes.plotting.comparison\_tool.compare(A:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
B: Union\[xarray.core.dataarray.DataArray,
xarray.core.dataset.Dataset\])**
